==> ZenTaoPMS.max2.0.rc1.php7.1.zip: zentaopms/module/baseline/lang/zh-tw.php <==
<?php
$lang->baseline->common         = '基線';
$lang->baseline->name           = '名稱';
$lang->baseline->template       = '文檔模板';
$lang->baseline->catalog        = '文檔目錄';
$lang->baseline->createTemplate = '創建模板';
$lang->baseline->editTemplate   = '編輯模板';
$lang->baseline->templateTitle  = '模板名稱';
$lang->baseline->templateType   = '模板類型';
$lang->baseline->docType        = '文檔類型';
$lang->baseline->docContent     = '文檔正文';
$lang->baseline->url            = '文檔URL';
$lang->baseline->manageChild    = '維護子目錄';
$lang->baseline->addedBy        = '由誰添加';
$lang->baseline->addedDate      = '添加時間';
$lang->baseline->files          = '附件';
$lang->baseline->view           = '模板詳情';
$lang->baseline->editBook       = '編輯手冊';
$lang->baseline->manageBook     = '維護章節';
$lang->baseline->addCatalogTip  = '暫時還沒有章節，';
$lang->baseline->editArticle    = '編輯內容';
$lang->baseline->articleView    = '文章內容';
$lang->baseline->editChapter    = '編輯章節';
$lang->baseline->chapter        = '章節';
$lang->baseline->chapterName    = '章節名稱';
$lang->baseline->baseInfo       = '基本信息';
$lang->baseline->chapterType    = '數據來源';
$lang->baseline->delete         = '刪除';

$lang->baseline->docTypeList['html']      = '富文本';
$lang->baseline->docTypeList['markdown']  = 'Markdown';
$lang->baseline->docTypeList['url']       = '連結';
$lang->baseline->docTypeList['book']      = 'Wiki';

$lang->baseline->chapterTypeList['input']  = '手動輸入';
$lang->baseline->chapterTypeList['system'] = '系統數據';

$lang->baseline->templateTypeList['']     = '';
$lang->baseline->templateTypeList['URS']  = '用戶需求說明書';
$lang->baseline->templateTypeList['SRS']  = '軟件需求規格說明書';
$lang->baseline->templateTypeList['HLDS'] = '概要設計說明書';
$lang->baseline->templateTypeList['DDS']  = '詳細設計文檔';
$lang->baseline->templateTypeList['DBDS'] = '資料庫設計文檔';
$lang->baseline->templateTypeList['ADS']  = '介面設計文檔';

$lang->baseline->confirmDelete = '您確定要刪除嗎?';

$lang->baseline->setting      = '設置';
$lang->baseline->version      = '版本號';
$lang->baseline->reviewer     = '評審人';
$lang->baseline->padding      = '序號補零';
$lang->baseline->reviewerRole = '評審人角色';

$lang->baseline->confirm[1] = '補零';
$lang->baseline->confirm[0] = '不補零';

$lang->baseline->objectType['PP']   = '項目計劃';
$lang->baseline->objectType['QAP']  = '質量保證計劃';
$lang->baseline->objectType['CMP']  = '配置管理計劃';
$lang->baseline->objectType['ITP']  = '整合測試計劃';
$lang->baseline->objectType['URS']  = '用戶需求說明書';
$lang->baseline->objectType['SRS']  = '軟件需求規格說明書';
$lang->baseline->objectType['HLDS'] = '概要設計說明書';
$lang->baseline->objectType['DDS']  = '產品詳細設計說明書';
$lang->baseline->objectType['Code'] = '程式碼';
$lang->baseline->objectType['ITTC'] = '整合測試用例';
$lang->baseline->objectType['STP']  = '系統測試計劃';
$lang->baseline->objectType['STTC'] = '系統測試用例';
$lang->baseline->objectType['UM']   = '用戶手冊';

$lang->baseline->versionForm['0']     = '';
$lang->baseline->versionForm['date1'] = '年月日';
$lang->baseline->versionForm['date2'] = '年-月-日';
$lang->baseline->versionForm['fixed'] = '固定值';
$lang->baseline->versionForm['user']  = '操作者';

$lang->baseline->joint['']  = '';
$lang->baseline->joint['.'] = '.';
$lang->baseline->joint['-'] = '-';
$lang->baseline->joint['_'] = '_';

==> ZenTaoPMS.max2.7.php5.3_5.6.zip: zentaopms/module/baseline/lang/zh-tw.php <==
<?php
$lang->baseline->common         = '基線';
$lang->baseline->name           = '名稱';
$lang->baseline->template       = '文檔模板';
$lang->baseline->catalog        = '文檔目錄';
$lang->baseline->createTemplate = '創建模板';
$lang->baseline->editTemplate   = '編輯模板';
$lang->baseline->templateTitle  = '模板名稱';
$lang->baseline->templateType   = '模板類型';
$lang->baseline->docType        = '文檔類型';
$lang->baseline->docContent     = '文檔正文';
$lang->baseline->url            = '文檔URL';
$lang->baseline->manageChild    = '維護子目錄';
$lang->baseline->addedBy        = '由誰添加';
$lang->baseline->addedDate      = '添加時間';
$lang->baseline->files          = '附件';
$lang->baseline->view           = '模板詳情';
$lang->baseline->editBook       = '編輯手冊';
$lang->baseline->manageBook     = '維護章節';
$lang->baseline->addCatalogTip  = '暫時還沒有章節，';
$lang->baseline->editArticle    = '編輯內容';
$lang->baseline->articleView    = '文章內容';
$lang->baseline->editChapter    = '編輯章節';
$lang->baseline->chapter        = '章節';
$lang->baseline->chapterName    = '章節名稱';
$lang->baseline->baseInfo       = '基本信息';
$lang->baseline->chapterType    = '數據來源';
$lang->baseline->delete         = '刪除';

$lang->baseline->docTypeList['html']      = '富文本';
$lang->baseline->docTypeList['markdown']  = 'Markdown';
$lang->baseline->docTypeList['url']       = '連結';
$lang->baseline->docTypeList['book']      = 'Wiki';

$lang->baseline->chapterTypeList['input']  = '手動輸入';
$lang->baseline->chapterTypeList['system'] = '系統數據';

$lang->baseline->confirmDelete = '您確定要刪除嗎?';

$lang->baseline->setting      = '設置';
$lang->baseline->version      = '版本號';
$lang->baseline->reviewer     = '評審人';
$lang->baseline->padding      = '序號補零';
$lang->baseline->reviewerRole = '評審人角色';

$lang->baseline->confirm[1] = '補零';
$lang->baseline->confirm[0] = '不補零';

$lang->baseline->objectList[''] = '';
$lang->baseline->objectList['PP']   = '項目計劃';
$lang->baseline->objectList['QAP']  = '質量保證計劃';
$lang->baseline->objectList['CMP']  = '配置管理計劃';
$lang->baseline->objectList['ITP']  = '整合測試計劃';
$lang->baseline->objectList['URS']  = '用戶需求說明書';
$lang->baseline->objectList['SRS']  = '軟件需求規格說明書';
$lang->baseline->objectList['HLDS'] = '概要設計說明書';
$lang->baseline->objectList['DDS']  = '詳細設計說明書';
$lang->baseline->objectList['DBDS'] = '資料庫設計文檔';
$lang->baseline->objectList['ADS']  = '介面設計文檔';
$lang->baseline->objectList['Code'] = '程式碼';
$lang->baseline->objectList['ITTC'] = '整合測試用例';
$lang->baseline->objectList['STP']  = '系統測試計劃';
$lang->baseline->objectList['STTC'] = '系統測試用例';
$lang->baseline->objectList['UM']   = '用戶手冊';

$lang->baseline->versionForm['0']     = '';
$lang->baseline->versionForm['date1'] = '年月日';
$lang->baseline->versionForm['date2'] = '年-月-日';
$lang->baseline->versionForm['fixed'] = '固定值';
$lang->baseline->versionForm['user']  = '操作者';

$lang->baseline->joint['']  = '';
$lang->baseline->joint['.'] = '.';
$lang->baseline->joint['-'] = '-';
$lang->baseline->joint['_'] = '_';
